document.getElementById('download-btn').addEventListener('click', async () => {
  const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });

  try {
    const result = await chrome.scripting.executeScript({
      target: { tabId: tab.id },
      function: extractCSS
    });

    const css = result[0]?.result || '';
    if (css) {
      downloadCSS(css, tab.url);
      document.getElementById('status').textContent = 'Downloading...';
    } else {
      document.getElementById('status').textContent = 'No CSS found.';
    }
  } catch (error) {
    console.error('Error executing script:', error);
    document.getElementById('status').textContent = 'Error fetching CSS.';
  }
});

function extractCSS() {
  const stylesheets = Array.from(document.styleSheets);
  let css = '';

  stylesheets.forEach(sheet => {
    try {
      const rules = Array.from(sheet.cssRules || []);
      rules.forEach(rule => {
        css += rule.cssText + '\n';
      });
    } catch (e) {
      console.warn('Could not access stylesheet:', sheet.href, e);
    }
  });

  return css;
}

function downloadCSS(css, url) {
  const blob = new Blob([css], { type: 'text/css' });
  const urlObject = URL.createObjectURL(blob);
  const link = document.createElement('a');
  link.href = urlObject;
  link.download = `${new URL(url).hostname}.css`;
  link.click();
  URL.revokeObjectURL(urlObject);
}
